@@ -20,12 +20,9 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: setup.h,v 1.26 2003/01/16 21:08:13 bagder Exp $
+ * $Id: setup.h,v 1.34 2003/10/14 12:00:45 bagder Exp $
  ***************************************************************************/
 
-/* MN 06/07/02 */
-/* #define HTTP_ONLY
-*/
 #ifdef HTTP_ONLY
 #define CURL_DISABLE_FTP
 #define CURL_DISABLE_LDAP
@@ -60,10 +57,10 @@
 
 #endif
 
-#ifndef __cplusplus        /* (rabe) */
+#if !defined(__cplusplus) && !defined(__BEOS__)
 typedef unsigned char bool;
 #define typedef_bool
-#endif                     /* (rabe) */
+#endif
 
 #ifdef NEED_REENTRANT
 /* Solaris machines needs _REENTRANT set for a few function prototypes and
@@ -122,6 +119,17 @@ defined(HAVE_LIBSSL) && defined(HAVE_LIBCRYPTO)
    */
 
 #ifdef WIN32
+
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN  /* Prevent including <winsock*.h> in <windows.h> */
+#endif
+
+#include <winsock2.h>        /* required by telnet.c */
+
+#if defined(ENABLE_IPV6) || defined(USE_SSLEAY)
+#include <ws2tcpip.h>
+#endif
+
 #if !defined(__GNUC__) || defined(__MINGW32__)
 #define sclose(x) closesocket(x)
 #define sread(x,y,z) recv(x,y,z,0)
@@ -135,29 +143,55 @@ defined(HAVE_LIBSSL) && defined(HAVE_LIBCRYPTO)
 #define HAVE_ALARM
 #endif
 
-#define PATH_CHAR     ";"
 #define DIR_CHAR      "\\"
 #define DOT_CHAR      "_"
 
+#else
+
+#ifdef DJGPP
+#define sclose(x)         close_s(x)
+#define sread(x,y,z)      read_s(x,y,z)
+#define swrite(x,y,z)     write_s(x,y,z)
+#define select(n,r,w,x,t) select_s(n,r,w,x,t)
+#define ioctl(x,y,z) ioctlsocket(x,y,(char *)(z))
+#define IOCTL_3_ARGS
+#include <tcp.h>
+#ifdef word
+#undef word
+#endif
+
+#else
+
+#ifdef __BEOS__
+#define sclose(x) closesocket(x)
+#define sread(x,y,z) (ssize_t)recv(x,y,z,0)
+#define swrite(x,y,z) (ssize_t)send(x,y,z,0)
 #else
 #define sclose(x) close(x)
 #define sread(x,y,z) recv(x,y,z,0)
 #define swrite(x,y,z) send(x,y,z,0)
+#endif
+
 #define HAVE_ALARM
 
-#define PATH_CHAR     ":"
+#endif
+
 #define DIR_CHAR      "/"
 #define DOT_CHAR      "."
 
-#ifdef HAVE_STRCASECMP
-/* this is for "-ansi -Wall -pedantic" to stop complaining! */
-extern int (strcasecmp)(const char *s1, const char *s2);
-extern int (strncasecmp)(const char *s1, const char *s2, size_t n);
+#ifdef DJGPP
+#undef DOT_CHAR
+#define DOT_CHAR      "_"
+#endif
+
 #ifndef fileno /* sunos 4 have this as a macro! */
 int fileno( FILE *stream);
 #endif
+
 #endif
 
+#if defined(ENABLE_IPV6) && defined(USE_ARES)
+#error "ares does not yet support IPv6. Disable IPv6 or ares and rebuild"
 #endif
 
 /*
@@ -173,6 +207,21 @@ typedef struct hostent Curl_addrinfo;
 typedef struct in_addr Curl_ipconnect;
 #endif
 
+#if 0
+#if (SIZEOF_OFF_T > 4)
+/* off_t is bigger than 4 bytes, and that makes it our prefered variable
+   type for filesizes */
+typedef off_t filesize_t;
+#else
+#ifdef HAVE_LONGLONG
+/* we have long long, use this for filesizes internally */
+typedef long long filesize_t;
+#else
+/* small off_t and no long long, no support for large files :-( */
+typedef long filesize_t;
+#endif /* didn't have long long */
+#endif /* sizeof wasn't bigger than 4 */
 
+#endif /* 0 */
 
 #endif /* __CONFIG_H */
